pub fn topological_sort(
nodes: &[&dyn Node],
edges: &[&Edge],
) -> Result<Vec<String>, GraphExecutionError>Expand description
Helper function to perform topological sort of nodes in a graph.
Returns nodes in execution order (sources first, sinks last). This ensures that when we execute nodes, all upstream nodes have already produced their output streams.